get.sensitivity.rhs <- function(lprec) {
  .Call(RlpSolve_get_sensitivity_rhs, lprec)
}
